fn decode_fp_pair(s: &str) -> Result<AuthCertKeyIds, &'static str>Expand description
Try to parse an authority fingerprint pair as it appears in URIs.
fn decode_fp_pair(s: &str) -> Result<AuthCertKeyIds, &'static str>Try to parse an authority fingerprint pair as it appears in URIs.