advance_state

Function advance_state 

fn advance_state(
    state: &mut Box<dyn DirState>,
    attempt_id: AttemptId,
) -> Result<(), AdvanceStateError>
Advances the progress of the directory download.

Returns Ok(()) if the state was successfully advanced.

Errors

  • Returns AdvanceStateError::AlreadyComplete if the directory has already been fully downloaded.
  • Returns AdvanceStateError::CantAdvanceYet if the directory is incomplete and the download cannot advance yet.