download_attempt

Function download_attempt 

async fn download_attempt<R: Runtime>(
    dirmgr: &Arc<DirMgr<R>>,
    state: &mut Box<dyn DirState>,
    parallelism: usize,
    attempt_id: AttemptId,
) -> Result<()>
Helper: Make a set of download attempts for the current directory state, and on success feed their results into the state object.

This can launch one or more download requests, but will not launch more than parallelism requests at a time.