no_more_than_a_week_from

Function no_more_than_a_week_from 

fn no_more_than_a_week_from(
    now: SystemTime,
    v: Option<SystemTime>,
) -> SystemTime
Helper: Clamp v so that it is no more than one week from now.

If v is absent, return the time that’s one week from now.

We use this to determine a reset time when no reset time is available, or when it is too far in the future.