fn note_cache_error<R: Runtime>(
circmgr: &CircMgr<R>,
source: &SourceInfo,
problem: &Error,
)Expand description
Record that a problem has occurred because of a failure in an answer from source.
fn note_cache_error<R: Runtime>(
circmgr: &CircMgr<R>,
source: &SourceInfo,
problem: &Error,
)Record that a problem has occurred because of a failure in an answer from source.