fn note_cache_success<R: Runtime>(circmgr: &CircMgr<R>, source: &SourceInfo)Expand description
Record that source has successfully given us some directory info.
fn note_cache_success<R: Runtime>(circmgr: &CircMgr<R>, source: &SourceInfo)Record that source has successfully given us some directory info.