macro_rules! propagate_fatal_errors {
( $e:expr ) => { ... };
}Expand description
Given a Result<()>, exit the current function if it is anything other than Ok(), or a nonfatal error.
macro_rules! propagate_fatal_errors {
( $e:expr ) => { ... };
}Given a Result<()>, exit the current function if it is anything other than Ok(), or a nonfatal error.