#[non_exhaustive]pub enum Dormancy {
Dormant,
Active,
}bridge-client only.Expand description
Active vs dormant state, as far as the bridge descriptor manager is concerned
This is usually derived in higher layers from arti_client::DormantMode,
whether TorClient::bootstrap() has been called, etc.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Dormant
Dormant (inactive)
Bridge descriptor downloads, or refreshes, will not be started.
In-progress downloads will be stopped if possible, but they may continue until they complete (or fail).
So a dormant BridgeDescMgr may still continue to
change the return value from bridges()
and continue to report BridgeDescEvents.
When the BridgeDescMgr is dormant,
bridges() may return stale descriptors
(that is, descriptors which ought to have been refetched and may no longer be valid),
or stale errors
(that is, errors which occurred some time ago,
and which would normally have been retried by now).
Active
Active
Bridge descriptors will be downloaded as requested.
When a bridge descriptor manager has been Dormant,
it may continue to provide stale data (as described)
for a while after it is made Active,
until the required refreshes and retries have taken place (or failed).