pub struct BridgeDescDownloadConfig {
parallelism: NonZeroU8,
retry: Duration,
prefetch: Duration,
min_refetch: Duration,
max_refetch: Duration,
}Expand description
Configuration for the BridgeDescMgr
Currently, the only way to make this is via its Default impl.
Fields
parallelism: NonZeroU8How many bridge descriptor downloads to attempt in parallel?
retry: DurationDefault/initial time to retry a failure to download a descriptor
(This has the semantics of an initial delay for RetryDelay,
and is used unless there is more specific retry information for the particular failure.)
prefetch: DurationWhen a downloaded descriptor is going to expire, how soon in advance to refetch it?
min_refetch: DurationMinimum interval between successive refetches of the descriptor for the same bridge
This limits the download activity which can be caused by an errant bridge.
If the descriptor’s validity information is shorter than this, we will use it after it has expired (rather than treating the bridge as broken).
max_refetch: DurationMaximum interval between successive refetches of the descriptor for the same bridge
This sets an upper bound on how old a descriptor we are willing to use. When this time expires, a refetch attempt will be started even if the descriptor is not going to expire soon.