struct Manager<R: Runtime, M: Mockable<R>> {
state: Mutex<State>,
runtime: R,
circmgr: M::CircMgr,
store: Arc<Mutex<Box<dyn Store>>>,
mockable: M,
}Expand description
The actual manager.
Fields
state: Mutex<State>The mutable state
runtime: RRuntime, used for tasks and sleeping
circmgr: M::CircMgrCircuit manager, used for creating circuits
store: Arc<Mutex<Box<dyn Store>>>Persistent state store
mockable: MMock for testing, usually ()
Implementations
Sourceimpl<R: Runtime, M: Mockable<R>> Manager<R, M>
impl<R: Runtime, M: Mockable<R>> Manager<R, M>
Sourcefn lock_then_process<'s>(self: &'s Arc<Self>) -> StateGuard<'s, R, M>
fn lock_then_process<'s>(self: &'s Arc<Self>) -> StateGuard<'s, R, M>
Obtain a lock on state, for functions that want to disrupt liveness properties
When StateGuard is dropped, the liveness properties will be restored
by making whatever progress is required.
See State.
Sourcefn lock_only(&self) -> MutexGuard<'_, State>
fn lock_only(&self) -> MutexGuard<'_, State>
Obtains the lock on state.
Caller ought not to modify state
so as to invalidate invariants or liveness properties.
Callers which are part of the algorithms in this crate
ought to consider lock_then_process instead.
Sourceimpl<R: Runtime, M: Mockable<R>> Manager<R, M>
impl<R: Runtime, M: Mockable<R>> Manager<R, M>
Sourceasync fn download_descriptor(
&self,
mockable: M,
bridge: &BridgeConfig,
config: &BridgeDescDownloadConfig,
) -> Result<Downloaded, Error>
async fn download_descriptor( &self, mockable: M, bridge: &BridgeConfig, config: &BridgeDescDownloadConfig, ) -> Result<Downloaded, Error>
Downloads a descriptor.
The core of the descriptor download task
launched by State::consider_launching.
Uses Mockable::download to actually get the document. So most of this function is parsing and checking.
The returned value is precisely the got input to
record_download_outcome.