pub(crate) struct ConsensusMeta {
lifetime: Lifetime,
sha3_256_of_signed: [u8; 32],
sha3_256_of_whole: [u8; 32],
}Expand description
Information about a consensus that we have in storage.
This information is ordinarily derived from the consensus, but doesn’t have to be.
Fields
lifetime: LifetimeThe time over which the consensus is valid.
sha3_256_of_signed: [u8; 32]A sha3-256 digest of the signed portion of the consensus: used for fetching diffs.
sha3_256_of_whole: [u8; 32]A sha3-256 digest of the entirety of the consensus: used for naming the file.
Implementations
Sourceimpl ConsensusMeta
impl ConsensusMeta
Sourcepub(crate) fn new(
lifetime: Lifetime,
sha3_256_of_signed: [u8; 32],
sha3_256_of_whole: [u8; 32],
) -> Self
pub(crate) fn new( lifetime: Lifetime, sha3_256_of_signed: [u8; 32], sha3_256_of_whole: [u8; 32], ) -> Self
Create a new ConsensusMeta
Sourcepub(crate) fn from_unvalidated(
signed_part: &str,
remainder: &str,
con: &UnvalidatedMdConsensus,
) -> Self
pub(crate) fn from_unvalidated( signed_part: &str, remainder: &str, con: &UnvalidatedMdConsensus, ) -> Self
Derive a new ConsensusMeta from an UnvalidatedMdConsensus and the text of its signed portion.
Sourcepub(crate) fn from_consensus(
signed_part: &str,
remainder: &str,
con: &MdConsensus,
) -> Self
pub(crate) fn from_consensus( signed_part: &str, remainder: &str, con: &MdConsensus, ) -> Self
Derive a new ConsensusMeta from a MdConsensus and the text of its signed portion.
Sourcepub(crate) fn sha3_256_of_signed(&self) -> &[u8; 32]
pub(crate) fn sha3_256_of_signed(&self) -> &[u8; 32]
Return the sha3-256 of the signed portion of this consensus.
Sourcepub(crate) fn sha3_256_of_whole(&self) -> &[u8; 32]
pub(crate) fn sha3_256_of_whole(&self) -> &[u8; 32]
Return the sha3-256 of the entirety of this consensus.