pub(crate) fn default_consensus_cutoff(
now: SystemTime,
tolerance: &DirTolerance,
) -> Result<SystemTime>Expand description
Given a time now, and an amount of tolerated clock skew tolerance,
return the age of the oldest consensus that we should request at that time.