fn client_download_range(lt: &Lifetime) -> (SystemTime, Duration)Expand description
Based on the lifetime for a consensus, return the time range during which clients should fetch the next one.
fn client_download_range(lt: &Lifetime) -> (SystemTime, Duration)Based on the lifetime for a consensus, return the time range during which clients should fetch the next one.