pub(crate) struct GetConsensusState<R: Runtime> {
cache_usage: CacheUsage,
after: Option<SystemTime>,
next: Option<GetCertsState<R>>,
authority_ids: Vec<RsaIdentity>,
rt: R,
config: Arc<DirMgrConfig>,
prev_netdir: Option<Arc<dyn PreviousNetDir>>,
filter: Arc<dyn DirFilter>,
}Expand description
Initial state: fetching or loading a consensus directory.
Fields
cache_usage: CacheUsageHow should we get the consensus from the cache, if at all?
after: Option<SystemTime>If present, a time after which we want our consensus to have been published.
next: Option<GetCertsState<R>>If present, our next state.
(This is present once we have a consensus.)
A list of RsaIdentity for the authorities that we believe in.
No consensus can be valid unless it purports to be signed by more than half of these authorities.
rt: RA Runtime implementation.
config: Arc<DirMgrConfig>The configuration of the directory manager. Used for download configuration purposes.
prev_netdir: Option<Arc<dyn PreviousNetDir>>If one exists, the netdir we’re trying to update.
filter: Arc<dyn DirFilter>A filter that gets applied to directory objects before we use them.
Implementations
Sourceimpl<R: Runtime> GetConsensusState<R>
impl<R: Runtime> GetConsensusState<R>
Sourcepub(crate) fn new(
rt: R,
config: Arc<DirMgrConfig>,
cache_usage: CacheUsage,
prev_netdir: Option<Arc<dyn PreviousNetDir>>,
filter: Arc<dyn DirFilter>,
) -> Self
pub(crate) fn new( rt: R, config: Arc<DirMgrConfig>, cache_usage: CacheUsage, prev_netdir: Option<Arc<dyn PreviousNetDir>>, filter: Arc<dyn DirFilter>, ) -> Self
Create a new GetConsensusState, using the cache as per cache_usage and downloading as
per the relevant sections of config. If prev_netdir is supplied, information from that
directory may be used to complete the next one.
Sourceimpl<R: Runtime> GetConsensusState<R>
impl<R: Runtime> GetConsensusState<R>
Sourcefn add_consensus_text(
&mut self,
source: DocSource,
text: &str,
cutoff: Option<SystemTime>,
changed: &mut bool,
) -> Result<&ConsensusMeta>
fn add_consensus_text( &mut self, source: DocSource, text: &str, cutoff: Option<SystemTime>, changed: &mut bool, ) -> Result<&ConsensusMeta>
Helper: try to set the current consensus text from an input string
text. Refuse it if the authorities could never be correct, or if it
is ill-formed.
If cutoff is provided, treat any consensus older than cutoff as
older-than-requested.
Errors from this method are not fatal to the download process.
Return true if id is an authority identity we recognize