SavedBlobHandle

Struct SavedBlobHandle 

pub(super) struct SavedBlobHandle<'a> {
    tx: Transaction<'a>,
    fname: String,
    digeststr: String,
    unlinker: Unlinker,
}
Handle to a blob that we have saved to disk but not yet committed to the database, and the database transaction where we added a reference to it.

Used to either commit the blob (by calling SavedBlobHandle::commit), or roll it back (by dropping the SavedBlobHandle without committing it.)

Fields

tx: Transaction<'a>

Transaction we’re using to add the blob to the ExtDocs table.

Note that struct fields are dropped in declaration order, so when we drop an uncommitted SavedBlobHandle, we roll back the transaction before we delete the file. (In practice, either order would be fine.)

fname: String

Filename for the file, with respect to the blob directory.

digeststr: String

Declared digest string for this blob. Of the format “digesttype-hexstr”.

unlinker: Unlinker

An ‘unlinker’ for the blob file.

Implementations

Source

impl<'a> SavedBlobHandle<'a>

pub(super) fn new( tx: Transaction<'a>, fname: String, digeststr: String, unlinker: Unlinker, ) -> Self

Construct a SavedBlobHandle from its parts.

pub(super) fn tx(&self) -> &Transaction<'a>

Return a reference to the underlying database transaction.

pub(super) fn digest_string(&self) -> &str

Return the digest string of the saved blob. Other tables use this as a foreign key into ExtDocs.digest

pub(super) fn fname(&self) -> &str

Return the filename of this blob within the blob directory.

pub(super) fn commit(self) -> Result<()>

Commit the relevant database transaction.