fn load_documents_from_store(
missing: &[DocId],
store: &dyn Store,
) -> Result<HashMap<DocId, DocumentText>>Expand description
Load a set of documents from a Store, returning all documents found in the store.
Note that this may be less than the number of documents in missing.