type BridgeKey = BridgeConfig;Expand description
The key we use in all our data structures
This type saves typing and would make it easier to change the bridge descriptor manager to take and handle another way of identifying the bridges it is working with.
Aliased Type
struct BridgeKey(/* private fields */);