pub(crate) struct SqliteStore {
conn: Connection,
sql_path: Option<PathBuf>,
blob_dir: CheckedDir,
lockfile: Option<LockFile>,
}Expand description
Local directory cache using a Sqlite3 connection.
Fields
conn: ConnectionConnection to the sqlite3 database.
sql_path: Option<PathBuf>Location for the sqlite3 database; used to reopen it.
blob_dir: CheckedDirLocation to store blob files.
lockfile: Option<LockFile>Lockfile to prevent concurrent write attempts from different processes.
If this is None we aren’t using a lockfile. Watch out!
(sqlite supports that with connection locking, but we want to be a little more coarse-grained here)
Implementations
Sourceimpl SqliteStore
impl SqliteStore
Sourcepub(crate) fn from_path_and_mistrust<P: AsRef<Path>>(
path: P,
mistrust: &Mistrust,
readonly: bool,
) -> Result<Self>
pub(crate) fn from_path_and_mistrust<P: AsRef<Path>>( path: P, mistrust: &Mistrust, readonly: bool, ) -> Result<Self>
Construct or open a new SqliteStore at some location on disk. The provided location must be a directory, or a possible location for a directory: the directory will be created if necessary.
If readonly is true, the result will be a read-only store. Otherwise, when readonly is false, the result may be read-only or read-write, depending on whether we can acquire the lock.
Limitations:
The file locking that we use to ensure that only one dirmgr is writing to a given storage directory at a time is currently per process. Therefore, you might get unexpected results if two SqliteStores are created in the same process with the path.
Sourcefn from_conn_internal(
conn: Connection,
blob_dir: CheckedDir,
readonly: bool,
) -> Result<Self>
fn from_conn_internal( conn: Connection, blob_dir: CheckedDir, readonly: bool, ) -> Result<Self>
Construct a new SqliteStore from a database connection and a location for blob files.
The readonly argument specifies whether the database connection should be read-only.
Sourcefn check_schema(&mut self, readonly: bool) -> Result<()>
fn check_schema(&mut self, readonly: bool) -> Result<()>
Check whether this database has a schema format we can read, and install or upgrade the schema if necessary.
Sourcefn read_blob(&self, path: &str) -> Result<StdResult<InputString, AbsentBlob>>
fn read_blob(&self, path: &str) -> Result<StdResult<InputString, AbsentBlob>>
Read a blob from disk, mapping it if possible.
Return Ok(Err(.)) if the file for the blob was not found on disk;
returns an error in other cases.
(See blob_consistency for information on why the blob might be absent.)
Sourcefn save_blob_internal(
&mut self,
contents: &[u8],
doctype: &str,
digest_type: &str,
digest: &[u8],
expires: OffsetDateTime,
) -> Result<SavedBlobHandle<'_>>
fn save_blob_internal( &mut self, contents: &[u8], doctype: &str, digest_type: &str, digest: &[u8], expires: OffsetDateTime, ) -> Result<SavedBlobHandle<'_>>
Write a file to disk as a blob, and record it in the ExtDocs table.
Return a SavedBlobHandle that describes where the blob is, and which can be used either to commit the blob or delete it.
See blob_consistency for more information on guarantees.
Sourcefn latest_consensus_internal(
&self,
flavor: ConsensusFlavor,
pending: Option<bool>,
) -> Result<StdResult<InputString, AbsentBlob>>
fn latest_consensus_internal( &self, flavor: ConsensusFlavor, pending: Option<bool>, ) -> Result<StdResult<InputString, AbsentBlob>>
As latest_consensus, but do not retry.
Sourcefn remove_blob_or_warn<P: AsRef<Path>>(&self, fname: P)
fn remove_blob_or_warn<P: AsRef<Path>>(&self, fname: P)
Remove the blob with name fname, but do not give an error on failure.
See blob_consistency: we should call this only having first ensured
that the blob is removed from the ExtDocs table.
Sourcefn remove_unreferenced_blobs(
&self,
now: OffsetDateTime,
expiration: &ExpirationConfig,
) -> Result<()>
fn remove_unreferenced_blobs( &self, now: OffsetDateTime, expiration: &ExpirationConfig, ) -> Result<()>
Delete any blob files that are old enough, and not mentioned in the ExtDocs table.
There shouldn’t typically be any, but we don’t want to let our cache grow infinitely if we have a bug.
Sourcefn remove_entries_for_vanished_blobs<'a>(
blob_dir: &CheckedDir,
tx: &Transaction<'a>,
) -> Result<usize>
fn remove_entries_for_vanished_blobs<'a>( blob_dir: &CheckedDir, tx: &Transaction<'a>, ) -> Result<usize>
Remove any entry in the ExtDocs table for which a blob file is vanished.
This method is O(n) in the size of the ExtDocs table and the size of the directory.
It doesn’t take self, to avoid problems with the borrow checker.